<?php

namespace Drupal\openstack\Plugin\cloud\config;

use Drupal\aws_cloud\Plugin\cloud\config\AwsCloudConfigPlugin;

/**
 * OpenStack cloud service provider (CloudConfig) plugin class.
 */
class OpenStackCloudConfigPlugin extends AwsCloudConfigPlugin {

  /**
   * {@inheritdoc}
   */
  public function getInstanceCollectionTemplateName() {
    return 'view.openstack_instance.list';
  }

  /**
   * {@inheritdoc}
   */
  public function loadCredentials($cloud_context) {
    /** @var \Drupal\cloud\Entity\CloudConfig $entity */
    $entity = $this->loadConfigEntity($cloud_context);
    $credentials = [];
    $openstack_ec2_api = $entity->get('field_use_openstack_ec2_api')->value;

    if (empty($openstack_ec2_api) && $entity !== FALSE) {
      $credentials['authUrl'] = $entity->get('field_api_endpoint')->value;
      $credentials['region'] = $entity->get('field_os_region')->value;
      $credentials['username'] = $entity->get('field_username')->value;
      $credentials['password'] = $entity->get('field_password')->value;
      $credentials['user_id'] = $entity->get('field_access_key')->value;
      $credentials['user_password'] = $entity->get('field_secret_key')->value;
      $credentials['domain_id'] = $entity->get('field_domain_id')->value;
      $credentials['project_id'] = $entity->get('field_project_id')->value;
    }
    elseif ($entity !== FALSE) {
      $credentials['region'] = $entity->get('field_os_region')->value;
      $credentials['endpoint'] = $entity->get('field_api_endpoint')->value;
      $credentials['ini_file'] = $this->fileSystem->realpath(aws_cloud_ini_file_path($entity->get('cloud_context')->value));
      // todo: this is hard-coded.
      $credentials['version'] = 'latest';
    }

    return $credentials;
  }

  /**
   * {@inheritdoc}
   */
  public function getPricingPageRoute() {
    return '';
  }

}
