<?php

namespace Drupal\openstack\Service\Rest;

use OpenStack\OpenStack;
use Drupal\cloud\Plugin\cloud\config\CloudConfigPluginManagerInterface;
use Drupal\cloud\Service\CloudServiceBase;

/**
 * Interacts with OpenStack using Native API.
 */
class OpenStackService extends CloudServiceBase {

  /**
   * Cloud context string.
   *
   * @var string
   */
  protected $cloudContext;

  /**
   * The cloud service provider plugin manager (CloudConfigPluginManager).
   *
   * @var \Drupal\cloud\Plugin\cloud\config\CloudConfigPluginManagerInterface
   */
  protected $cloudConfigPluginManager;

  /**
   * Guzzle client.
   *
   * @var \GuzzleHttp\Client
   */
  protected $httpClient;

  /**
   * Constructs a new OpenStackService object.
   *
   * @param \Drupal\cloud\Plugin\cloud\config\CloudConfigPluginManagerInterface $cloud_config_plugin_manager
   *   The cloud service provider plugin manager (CloudConfigPluginManager).
   */
  public function __construct(CloudConfigPluginManagerInterface $cloud_config_plugin_manager) {

    // The parent constructor takes care of $this->messenger object.
    parent::__construct();

    $this->cloudConfigPluginManager = $cloud_config_plugin_manager;
  }

  /**
   * {@inheritdoc}
   */
  public function setCloudContext($cloud_context) {
    $this->cloudContext = $cloud_context;
    $this->cloudConfigPluginManager->setCloudContext($cloud_context);
  }

  /**
   * Load and return an Client.
   *
   * @return object
   *   The value of created object.
   */
  public function getClient() {
    $credentials = $this->cloudConfigPluginManager->loadCredentials();

    try {
      $params = [
        'authUrl'    => $credentials['authUrl'],
        'region'     => $credentials['region'],
        'user'       => [
          'name'     => $credentials['username'],
          'password' => $credentials['password'],
          'domain'   => ['id' => $credentials['domain_id']],
        ],
        'scope'      => ['project' => ['id' => $credentials['project_id']]],
      ];

      $client = new OpenStack($params);
    }
    catch (\Exception $e) {
      $this->logger('openstack.rest')->error($e->getMessage());
    }
    return $client;
  }

  /**
   * Helper static method to clear cache.
   */
  public static function clearCacheValue() {
    \Drupal::cache('menu')->invalidateAll();
    \Drupal::service('cache.render')->deleteAll();
    \Drupal::service('router.builder')->rebuild();
    \Drupal::service('plugin.cache_clearer')->clearCachedDefinitions();
  }

}
