<?php

namespace Drupal\cloud\Form;

use Drupal\cloud\Entity\CloudStore;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form controller for cloud store edit forms.
 *
 * @ingroup cloud_Project
 */
class CloudStoreForm extends CloudContentForm {

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    /** @var \Drupal\cloud\Entity\CloudStore $entity */
    $entity = $this->entity;
    $cloud_store_type = $entity->bundle();
    $form = parent::buildForm($form, $form_state);
    $weight = -50;

    if (!$this->entity->isNew()) {
      $form['new_revision'] = [
        '#type' => 'checkbox',
        '#title' => $this->t('Create new revision'),
        '#default_value' => FALSE,
        '#weight' => $weight++,
        'hidden' => TRUE,
      ];
    }

    $form = $this->reorderFieldset($form, $cloud_store_type);

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $entity = $this->entity;

    // Save as a new revision if requested to do so.
    if (!$form_state->isValueEmpty('new_revision') && $form_state->getValue('new_revision') !== FALSE) {
      $entity->setNewRevision();

      // If a new revision is created, save the current user as revision author.
      $entity->setRevisionCreationTime(\Drupal::time()->getRequestTime());
      $entity->setRevisionUserId($this->currentUser()->id());
    }
    else {
      $entity->setNewRevision(FALSE);
    }
    // Save entity.
    $entity->save();

    // Clear block and menu cache.
    $form_state->setRedirect('entity.cloud_store.canonical', [
      'cloud_store' => $entity->id(),
      'cloud_store_type' => $entity->bundle(),
    ]);
    CloudStore::updateCache();
  }

  /**
   * Add the build array of fieldset others.
   *
   * @param array &$form
   *   The form array.
   * @param string $cloud_store_type
   *   Cloud store type.
   *
   * @return array
   *   The formulated form array.
   */
  protected function reorderFieldset(array &$form, $cloud_store_type = '') {
    $entity_type = $this->entity->getEntityType()->id();
    $field_definitions = \Drupal::service('entity_field.manager')->getFieldDefinitions($entity_type, $cloud_store_type);
    $temp = [];
    foreach ($field_definitions ?: [] as $key => $value) {
      if (preg_match('/field_(\w+)/', $key)) {
        $temp[] = $key;
      }
    }

    $fieldsets_def = [
      [
        'name' => 'store',
        'title' => t('Store name'),
        'open' => TRUE,
        'fields' => [
          'name',
        ],
      ],
      [
        'name' => 'parameter',
        'title' => t('Parameter'),
        'open' => TRUE,
        'fields' => $temp,
      ],
      [
        'name' => 'others',
        'title' => t('Others'),
        'open' => FALSE,
        'fields' => [
          'revision_log_message',
          'cloud_context',
          'uid',
        ],
      ],
    ];

    \Drupal::service('cloud')->reorderForm($form, $fieldsets_def);
    return $form;
  }

}
